@@ -13,5 +13,17 @@
 #    under the License.
 
 DEFAULT_OVSDB_CONNECTION = 'tcp:127.0.0.1:6640'
+DEFAULT_OVNNB_CONNECTION = 'tcp:127.0.0.1:6641'
 DEFAULT_TIMEOUT = 5
 DEVICE_NAME_MAX_LEN = 14
+
+
+ACL_PRIORITY_MAX = 32767
+
+NAT_SNAT = 'snat'
+NAT_DNAT = 'dnat'
+NAT_BOTH = 'dnat_and_snat'
+NAT_TYPES = (NAT_SNAT, NAT_DNAT, NAT_BOTH)
+
+PROTO_TCP = 'tcp'
+PROTO_UDP = 'udp'
